@@ -21,7 +21,7 @@ from IPython.lib.lexers import IPythonLexer, IPython3Lexer
 from pygments.lexers import get_lexer_by_name
 from pygments.util import ClassNotFound
 from qtconsole import __version__
-from traitlets import Bool, Unicode
+from traitlets import Bool, Unicode, observe, default
 from .frontend_widget import FrontendWidget
 from . import styles
 
@@ -133,6 +133,9 @@ class JupyterWidget(IPythonWidget):
         else:
             self.set_default_style()
 
+        # Initialize language name.
+        self.language_name = None
+
     #---------------------------------------------------------------------------
     # 'BaseFrontendMixin' abstract interface
     #
@@ -288,7 +291,7 @@ class JupyterWidget(IPythonWidget):
     def _handle_kernel_info_reply(self, rep):
         """Handle kernel info replies."""
         content = rep['content']
-        language_name = content['language_info']['name']
+        self.language_name = content['language_info']['name']
         pygments_lexer = content['language_info'].get('pygments_lexer', '')
 
         try:
@@ -299,7 +302,7 @@ class JupyterWidget(IPythonWidget):
             elif pygments_lexer == 'ipython2':
                 lexer = IPythonLexer()
             else:
-                lexer = get_lexer_by_name(language_name)
+                lexer = get_lexer_by_name(self.language_name)
             self._highlighter._lexer = lexer
         except ClassNotFound:
             pass
@@ -558,7 +561,8 @@ class JupyterWidget(IPythonWidget):
 
     #------ Trait change handlers --------------------------------------------
 
-    def _style_sheet_changed(self):
+    @observe('style_sheet')
+    def _style_sheet_changed(self, changed=None):
         """ Set the style sheets of the underlying widgets.
         """
         self.setStyleSheet(self.style_sheet)
@@ -568,7 +572,8 @@ class JupyterWidget(IPythonWidget):
         if self._page_control is not None:
             self._page_control.document().setDefaultStyleSheet(self.style_sheet)
 
-    def _syntax_style_changed(self):
+    @observe('syntax_style')
+    def _syntax_style_changed(self, changed=None):
         """ Set the style for the syntax highlighter.
         """
         if self._highlighter is None:
@@ -582,6 +587,7 @@ class JupyterWidget(IPythonWidget):
 
     #------ Trait default initializers -----------------------------------------
 
+    @default('banner')
     def _banner_default(self):
         return "Jupyter QtConsole {version}\n".format(version=__version__)
 
